@@ -526,12 +526,12 @@ void KbStateApplet::initMasks() {
    }
    state = 0;
    
-   for (int i = 0; modifierKeys[i].name != ""; i++) {
+   for (int i = 0; strcmp(modifierKeys[i].name, "") != 0; i++) {
       int mask = modifierKeys[i].mask;
       if (mask == 0)
          if (modifierKeys[i].keysym != 0)
             mask = XkbKeysymToModifiers (this->x11Display(), modifierKeys[i].keysym);
-         else if (modifierKeys[i].name == "Win")
+         else if (!strcmp(modifierKeys[i].name, "Win"))
             mask = KKeyNative::modX(KKey::WIN);
          else
             mask = XkbKeysymToModifiers (this->x11Display(), XK_Mode_switch)
@@ -787,7 +787,7 @@ void KeyIcon::updateImages () {
    int size = width()<height() ? width() : height();
 
    locked    = instance->iconLoader()->loadIcon("lock_overlay", KIcon::Panel, size-4);
-	if (modifierKeys[keyId].icon != "") {
+	if (strcmp(modifierKeys[keyId].icon, "")) {
 	   latched   = instance->iconLoader()->loadIcon(modifierKeys[keyId].icon, KIcon::NoGroup, size-4);
    	unlatched = instance->iconLoader()->loadIcon(modifierKeys[keyId].icon, KIcon::NoGroup, size-4);
 		
@@ -812,14 +812,14 @@ void KeyIcon::drawButton (QPainter *p) {
    if (isLocked || isLatched) {
       qDrawShadePanel (p, 0, 0, width(), height(), colorGroup(), true, 1, NULL);
       p->fillRect (1,1,width()-2,height()-2, KGlobalSettings::highlightColor());
-		if (modifierKeys[keyId].icon != "")
+		if (strcmp(modifierKeys[keyId].icon, ""))
 			p->drawPixmap (x+1,y+1, latched);
       black = KGlobalSettings::highlightedTextColor();
       o = 1;
    }
    else {
       qDrawShadePanel (p, 0, 0, width(), height(), colorGroup(), false, 1, NULL);
-		if (modifierKeys[keyId].icon != "")
+		if (strcmp(modifierKeys[keyId].icon, ""))
 			p->drawPixmap (x,y, unlatched);
       black = KGlobalSettings::textColor();
    }
@@ -831,7 +831,7 @@ void KeyIcon::drawButton (QPainter *p) {
       QFontMetrics metrics(font);
       QRect rect = metrics.boundingRect (text);
       int size;
-      if (modifierKeys[keyId].name == "Alt Graph")
+      if (!strcmp(modifierKeys[keyId].name, "Alt Graph"))
          size = rect.width()>rect.height()?rect.width():rect.height();
       else
          size = rect.width()>12*rect.height()/5?rect.width():12*rect.height()/5;
@@ -843,7 +843,7 @@ void KeyIcon::drawButton (QPainter *p) {
 
       p->setPen (black);
       p->setFont (font);
-      if (modifierKeys[keyId].name == "Alt Graph")
+      if (!strcmp(modifierKeys[keyId].name, "Alt Graph"))
       p->drawText (o,o, width(), height(), Qt::AlignCenter, text);
       else
          p->drawText (o,o, width(), height()*(251)/384, Qt::AlignCenter, text);
